@@ -17,8 +17,8 @@
  *  You should have received a copy of the GNU Lesser General Public
  */
 
-#ifndef BARGRAPHCORE_H
-#define BARGRAPHCORE_H
+#ifndef BARCHARTCORE_H
+#define BARCHARTCORE_H
 
 #include "chartcore.h"
 
@@ -29,9 +29,9 @@ class BarChartCore : public ChartCore
 public:
     explicit BarChartCore(QQuickItem* parent = 0);
     qreal barWidth() const;
-    void paint(QPainter* painter);
+    void paint(QPainter* painter) override;
 Q_SIGNALS:
     void barWidthChanged();
 };
 
-#endif // BARGRAPHCORE_H
+#endif // BARCHARTCORE_H
